---
title: '[릴리즈노트] 2024-09-27 원 페이먼트 인프라 업데이트'
category: 업데이트
tags:
  - OPI
  - 업데이트
searchTags:
  - 위변조 확인
  - 거래대사
  - 원 페이먼트 인프라
  - 업데이트
datetime: 2025-02-13T06:02:32.259Z
---

<Callout title="2024년 9월 27일 원 페이먼트 인프라 업데이트 소식을 안내드립니다." />



## **주요 업데이트 사항**

<Tag text="PG 거래대사" />

✔️ 이제 콘솔 내 PG 거래대사에서 조회한 데이터를 엑셀로 다운로드하여 사용해 보세요.



PG 거래대사 내의 거래 정산 내역 메뉴에서 정산일 또는 거래일을 기준으로, 거래 건별 조회 메뉴에서는 정산일을 기준으로 최대 3개월 분량의 데이터를 엑셀로 다운로드할 수 있습니다.

<Tag text="PG 거래대사" />

✔️ KSNET, KPN, 하이픈에서 발생한 거래 건도 PG 거래대사에서 데이터 확인이 가능해집니다.

기존에 12개 PG사 (KCP, KG이니시스, 나이스페이먼츠, 토스페이, 네이버페이, 다날, 페이코, (구)토스페이먼츠, 토스페이먼츠, 카카오페이, 엑심베이, 헥토파이낸셜) 에서만 지원하던 PG 거래대사가 KSNET, KPN, 하이픈까지 확장하여 총 15개 PG사 데이터에 한하여 제공됩니다.

(참고 : PG 거래대사 메뉴의 경우 클로즈 베타로 운영되고 있으며, 사용을 원하시는 고객께서는 [PG거래대사 베타서비스 신청 바로가기 ↗](https://forms.gle/cZAqJLGqovC1STrS8)에서 신청해 주시길 바랍니다.)

<Tag text="결제모듈 V1" />

✔️ 엑심베이 결제시 결제 금액 위변조 확인이 강화됩니다.

기존에는 엑심베이로부터 전달받은 값 자체에 위변조 내용이 있는지 hash만 검증했으나 앞으로는 hash 검증에 추가로 실제 결제금액까지 비교하여 금액을 위변조하여 결제가 승인되지 않도록 로직을 추가하였습니다.

[\[원 페이먼트 인프라 릴리즈노트\] 2024-09-27 업데이트 보러가기↗](https://developers.portone.io/release-notes/api-sdk/2024-09-27)
